/* $Id: cpumask.h,v 1.3 2003/09/07 20:15:38 mikpe Exp $
 * Performance-monitoring counters driver.
 * Partial simulation of cpumask_t on non-cpumask_t kernels.
 * Extension to allow inspecting a cpumask_t as array of ulong.
 * Appropriate definition of perfctr_cpus_forbidden_mask.
 *
 * Copyright (C) 2003  Mikael Pettersson
 */

/* 2.6.0-test4 changed set-of-CPUs values from ulong to cpumask_t */
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)

#ifndef PERFCTR_HAVE_CPUMASK_T
typedef unsigned long cpumask_t;
#endif

#define cpu_set(cpu, map)	atomic_set_mask((1UL << (cpu)), &(map))
#define cpu_isset(cpu, map)	((map) & (1UL << (cpu)))
#define cpus_and(dst,src1,src2)	do { (dst) = (src1) & (src2); } while(0)
#define cpus_clear(map)		do { (map) = 0UL; } while(0)
#define cpus_complement(map)	do { (map) = ~(map); } while(0)
#define cpus_empty(map)		((map) == 0UL)
#define cpus_equal(map1, map2)	((map1) == (map2))

#define CPU_MASK_NONE		0UL

#endif

#ifdef CPU_ARRAY_SIZE
#define PERFCTR_CPUMASK_NRLONGS	CPU_ARRAY_SIZE
#define perfctr_cpus_mask(cpus)	((cpus).mask)
#else
#define PERFCTR_CPUMASK_NRLONGS	1
#define perfctr_cpus_mask(cpus)	(&(cpus))
#endif

/* `perfctr_cpus_forbidden_mask' used to be defined in <asm/perfctr.h>,
   but cpumask_t compatibility issues forced it to be moved here. */
#if PERFCTR_CPUS_FORBIDDEN_MASK_NEEDED
extern cpumask_t perfctr_cpus_forbidden_mask;
#else
#define perfctr_cpus_forbidden_mask	CPU_MASK_NONE
#endif
